pub struct Renderer {
pub surface: Surface<'static>,
pub device: Device,
pub queue: Queue,
pub config: SurfaceConfiguration,
/* private fields */
}Fields
surface: Surface<'static>device: Devicequeue: Queueconfig: SurfaceConfigurationImplementations
Sourceimpl Renderer
impl Renderer
pub async fn new(window: &'static Window) -> Result<Self>
pub fn scale_factor(&self) -> f32
pub fn resize(&mut self, width: u32, height: u32)
pub fn resize_with_scale(&mut self, width: u32, height: u32, scale_factor: f32)
pub fn resize_with_logical_viewport( &mut self, surface_width: u32, surface_height: u32, scale_factor: f32, logical_width: u32, logical_height: u32, viewport_x: u32, viewport_y: u32, viewport_width: u32, viewport_height: u32, )
pub fn logical_size(&self) -> (u32, u32)
pub fn render_sprites( &mut self, images: &ImageManager, sprites: &[RenderSprite], ) -> Result<()>
pub fn debug_read_render_chain_textures( &self, ) -> Result<Vec<RendererDebugTexture>>
Sourcepub fn clear_runtime_image_textures(&mut self)
pub fn clear_runtime_image_textures(&mut self)
Drop GPU textures that are keyed by runtime ImageId.
Scene restart reinitializes ImageManager and reuses ImageId indices from 0. Keeping the old GPU cache would make a newly decoded image with the same ImageId/version sample the previous scene’s texture. External path based textures are intentionally kept because their keys are stable resource paths.